@@ -73,8 +73,8 @@ VisualizerCallableInterface = Union[
     Callable[..., LeapImageWithHeatmap]
 ]
 
-VisualizerCallableReturnType = Union[LeapImage, LeapText, LeapGraph, LeapHorizontalBar,
-LeapImageMask, LeapTextMask, LeapImageWithBBox, LeapImageWithHeatmap]
+LeapData = Union[LeapImage, LeapText, LeapGraph, LeapHorizontalBar, LeapImageMask, LeapTextMask, LeapImageWithBBox,
+LeapImageWithHeatmap]
 
 CustomCallableInterface = Callable[..., Any]
 
@@ -109,6 +109,7 @@ class MetricHandler:
     arg_names: List[str]
     direction: Optional[MetricDirection] = MetricDirection.Downward
 
+
 @dataclass
 class RawInputsForHeatmap:
     raw_input_by_vizualizer_arg_name: Dict[str, npt.NDArray[np.float32]]
